%define debug_package %{nil}
%define _requires_exceptions perl(Exporter)\\|perl(XSLoader)
%define python_compile python -c "import compileall; compileall.compile_dir('.')" 
%define python_compile_opt python -O -c "import compileall; compileall.compile_dir('.')" 

%define python3_compile python3 -c "import compileall; compileall.compile_dir('.')" 
%define python3_compile_opt python3 -O -c "import compileall; compileall.compile_dir('.')"

%define build_py3 1
%define	with_docs 1

Summary:	A framework for configuring, compiling and installing applications
Name:		waf
Version:	1.8.16
Release:	%mkrel 1
License:	BSD and Python
Group:		Development/Tools
Url:		http://code.google.com/p/waf/
Source0:	waf-%{version}.stripped.tar.xz
Source1:	%{name}.macros
Source2:	%{name}-python3.macros
Source3:	repack.sh
Patch0:		%{name}-1.6.3-libdir.patch
Patch1:         %{name}-1.6.9-logo.patch
BuildRequires:  python-devel
Requires:	python(abi) = %{pyver}
BuildArch:	noarch
%if %{build_py3}
BuildRequires:  python3-devel
%endif
%if %{with_docs}
BuildRequires:	python-sphinx
BuildRequires:	graphviz
BuildRequires:	imagemagick
Suggests:       %{name}-doc
%endif
BuildConflicts: waf
%if %{build_py3}
BuildConflicts: waf-python3
%endif

%description
Waf is a Python-based framework for configuring, compiling and installing
applications. It derives from the concepts of other build tools such as 
Scons, Autotools, CMake, and Ant.

%if %{with_docs}
%package -n %{name}-doc
Summary:        Documentation for %{name}
%description -n %{name}-doc
Waf is a Python-based framework for configuring, compiling and
installing applications. It is a replacement for other tools such as
Autotools, Scons, CMake or Ant.
This package contains the HTML documentation for %{name}.
%endif

%if %{build_py3}
%package -n %{name}-python3
Summary:        Python3 support for %{name}
Requires:	python(abi) = %{py3ver}

%description -n %{name}-python3
Waf is a Python-based framework for configuring, compiling and
installing applications. It is a replacement for other tools such as
Autotools, Scons, CMake or Ant.

This package contains the Python 3 version of %{name}.
%endif

%prep
%setup -q
%patch0 -p0 -b .libdir
%patch1 -p1 -b .logo

# remove BOM, causes trouble later
sed -i -e '1s/^\xEF\xBB\xBF//' waflib/extras/dpapi.py

# add missing quotes, see rhbz#914566 and
# https://code.google.com/p/waf/issues/detail?id=1263
sed -i -e 's@fontname=\(Vera.*sans\),@fontname="\1",@g' \
  docs/sphinx/conf.py \
  docs/sphinx/coremodules.rst \
  docs/sphinx/featuremap.rst

%build
extras=
for f in waflib/extras/*.py ; do
  f=$(basename "$f" .py);
  if [ "$f" != "__init__" ]; then
    extras="${extras:+$extras,}$f" ;
  fi
done
./waf-light --make-waf --strip --tools="$extras"

%if %{with_docs}
# build html docs
pushd docs/sphinx
../../waf configure build
popd
%endif

%install
# use waf so it unpacks itself
mkdir _temp ; pushd _temp
cp -av ../waf .
python ./waf >/dev/null 2>&1
pushd .waf-%{version}-*
find . -name '*.py' -printf '%%P\0' |
  xargs -0 -I{} install -m 0644 -p -D {} %{buildroot}%{_datadir}/waf/{}
popd

%if %{build_py3}
python3 ./waf >/dev/null 2>&1
pushd .waf3-%{version}-*
find . -name '*.py' -printf '%%P\0' |
  xargs -0 -I{} install -m 0644 -p -D {} %{buildroot}%{_datadir}/waf3/{}
popd
%endif
popd

install -m 0755 -p -D waf-light %{buildroot}%{_bindir}/waf-%{python_version}

%if %{build_py3}
install -m 0755 -p -D waf-light %{buildroot}%{_bindir}/waf-%{python3_version}
%endif

ln -s waf-%{python_version} %{buildroot}%{_bindir}/waf

# remove shebangs from and fix EOL for all scripts in wafadmin
find %{buildroot}%{_datadir}/ -name '*.py' \
     -exec sed -i -e '1{/^#!/d}' -e 's|\r$||g' {} \;

# fix waf script shebang line
sed -i "1c#! %{__python}" %{buildroot}%{_bindir}/waf-%{python_version}
%if %{build_py3}
sed -i "1c#! %{__python3}" %{buildroot}%{_bindir}/waf-%{python3_version}
%endif

# remove x-bits from everything going to doc
find demos utils -type f -exec chmod 0644 {} \;

# remove hidden file
rm -f docs/sphinx/build/html/.buildinfo

# install waf rpm macro helper
install -D %{SOURCE1} %{buildroot}%{_sysconfdir}/rpm/macros.d/%{name}.macros
%if %{build_py3}
install -D %{SOURCE2} %{buildroot}%{_sysconfdir}/rpm/macros.d/%{name}-python3.macros
%endif

# do byte compilation
pushd %{buildroot}%{_datadir}/waf
%python_compile_opt 
%python_compile 
popd

%if %{build_py3}
pushd %{buildroot}%{_datadir}/waf3
%python3_compile_opt
%python3_compile
popd
%endif

%if %{with_docs}
%files -n %{name}-doc
%doc docs/sphinx/build/html
%doc README TODO ChangeLog demos
%endif

%files 
%{_sysconfdir}/rpm/macros.d/%{name}.macros
%{_bindir}/%{name}
%{_bindir}/%{name}-%{python_version}
%{_datadir}/%{name}

%if %{build_py3}
%files -n %{name}-python3
%{_sysconfdir}/rpm/macros.d/%{name}-python3.macros
%{_bindir}/waf-%{python3_version}
%{_datadir}/waf3
%endif


%changelog
* Wed Nov 04 2015 bb <bb> 1.8.16-1pclos2015
- update

* Sat Aug 29 2015 bb <bb> 1.8.12-1pclos2015
- update

* Wed May 20 2015 bb <bb> 1.8.9-1pclos2015
- update

